==> message-facade-2.0.2-20210623.091445-69-sources.jar: com/bizvane/messagefacade/models/vo/SendTuWenMessageVO.java <==
package com.bizvane.messagefacade.models.vo;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

/**
 * Created by yunjie.tian on 2018/7/16.
 */
public class SendTuWenMessageVO implements Serializable {

	private static final long serialVersionUID = 1L;


	@ApiModelProperty(value = "所属企业id", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;

	@io.swagger.annotations.ApiModelProperty(value = "品牌", name = "brandId", required = false, example = "")
	private Long brandId;

	@ApiModelProperty(value = "任务Id", name = "taskId", required = false, example = "")
	private Long taskId;

	@ApiModelProperty(value = "任务code", name = "taskCode", required = false, example = "")
	private String taskCode;

	@io.swagger.annotations.ApiModelProperty(value = "会员openid", name = "openId", required = false, example = "")
	private String openIdS;

	@io.swagger.annotations.ApiModelProperty(value = "会员人数", name = "openId", required = false, example = "")
	private String memberSum;


	@io.swagger.annotations.ApiModelProperty(value = "模板id", name = "mediaId", required = false, example = "")
	private String mediaId;

	@io.swagger.annotations.ApiModelProperty(value = "消息类型", name = "msgType", required = false, example = "")
	private String msgType;

	@io.swagger.annotations.ApiModelProperty(value = "是否继续群发", name = "图文消息被判定为转载时，是否继续群发。 1为继续群发（转载），0为停止群发。 该参数默认为0。", required = false, example = "")
	private String sendIgnoreReprint;

	@io.swagger.annotations.ApiModelProperty(value = "分组名称", name = "groupName", required = false, example = "")
	private String groupName;
	@io.swagger.annotations.ApiModelProperty(value = "消息标题", name = "groupName", required = false, example = "")
	private String headlTitle;


	public Long getBrandId() {
		return brandId;
	}

	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}


	public String getOpenIdS() {
		return openIdS;
	}

	public void setOpenIdS(String openIdS) {
		this.openIdS = openIdS;
	}

	public String getMediaId() {
		return mediaId;
	}

	public void setMediaId(String mediaId) {
		this.mediaId = mediaId;
	}

	public String getMsgType() {
		return msgType;
	}

	public void setMsgType(String msgType) {
		this.msgType = msgType;
	}

	public String getSendIgnoreReprint() {
		return sendIgnoreReprint;
	}

	public void setSendIgnoreReprint(String sendIgnoreReprint) {
		this.sendIgnoreReprint = sendIgnoreReprint;
	}

	public String getGroupName() {
		return groupName;
	}

	public void setGroupName(String groupName) {
		this.groupName = groupName;
	}

	public String getHeadlTitle() {
		return headlTitle;
	}

	public void setHeadlTitle(String headlTitle) {
		this.headlTitle = headlTitle;
	}

	public String getMemberSum() {
		return memberSum;
	}

	public void setMemberSum(String memberSum) {
		this.memberSum = memberSum;
	}

	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}


	public Long getTaskId() {
		return taskId;
	}

	public void setTaskId(Long taskId) {
		this.taskId = taskId;
	}

	public String getTaskCode() {
		return taskCode;
	}

	public void setTaskCode(String taskCode) {
		this.taskCode = taskCode;
	}

	public static long getSerialversionuid() {
		return serialVersionUID;
	}


}

==> message-facade-2.0.12-20250805.051308-2-sources.jar: com/bizvane/messagefacade/models/vo/SendTuWenMessageVO.java <==
package com.bizvane.messagefacade.models.vo;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.List;

/**
 * Created by yunjie.tian on 2018/7/16.
 */
public class SendTuWenMessageVO implements Serializable {

	private static final long serialVersionUID = 1L;


	@ApiModelProperty(value = "所属企业id", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;

	@io.swagger.annotations.ApiModelProperty(value = "品牌", name = "brandId", required = false, example = "")
	private Long brandId;

	@ApiModelProperty(value = "任务Id", name = "taskId", required = false, example = "")
	private Long taskId;

	@ApiModelProperty(value = "任务code", name = "taskCode", required = false, example = "")
	private String taskCode;

	@io.swagger.annotations.ApiModelProperty(value = "会员openid", name = "openId", required = false, example = "")
	private String openIdS;

	@io.swagger.annotations.ApiModelProperty(value = "会员人数", name = "openId", required = false, example = "")
	private String memberSum;


	@io.swagger.annotations.ApiModelProperty(value = "模板id", name = "mediaId", required = false, example = "")
	private String mediaId;

	@io.swagger.annotations.ApiModelProperty(value = "消息类型", name = "msgType", required = false, example = "")
	private String msgType;

	@io.swagger.annotations.ApiModelProperty(value = "是否继续群发", name = "图文消息被判定为转载时，是否继续群发。 1为继续群发（转载），0为停止群发。 该参数默认为0。", required = false, example = "")
	private String sendIgnoreReprint;

	@io.swagger.annotations.ApiModelProperty(value = "分组名称", name = "groupName", required = false, example = "")
	private String groupName;
	@io.swagger.annotations.ApiModelProperty(value = "消息标题", name = "groupName", required = false, example = "")
	private String headlTitle;

	@io.swagger.annotations.ApiModelProperty(value = "发送会员集合", name = "successMembers", required = false, example = "")
	private List<SendTuWenMembersInfoVO> successMembers;

	@io.swagger.annotations.ApiModelProperty(value = "未发送会员集合", name = "failMembers", required = false, example = "")
	private List<SendTuWenMembersInfoVO> failMembers;

	@ApiModelProperty(value = "活动Id", name = "mktActivityId", required = false, example = "")
	private Long mktActivityId;

	public Long getBrandId() {
		return brandId;
	}

	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}


	public String getOpenIdS() {
		return openIdS;
	}

	public void setOpenIdS(String openIdS) {
		this.openIdS = openIdS;
	}

	public String getMediaId() {
		return mediaId;
	}

	public void setMediaId(String mediaId) {
		this.mediaId = mediaId;
	}

	public String getMsgType() {
		return msgType;
	}

	public void setMsgType(String msgType) {
		this.msgType = msgType;
	}

	public String getSendIgnoreReprint() {
		return sendIgnoreReprint;
	}

	public void setSendIgnoreReprint(String sendIgnoreReprint) {
		this.sendIgnoreReprint = sendIgnoreReprint;
	}

	public String getGroupName() {
		return groupName;
	}

	public void setGroupName(String groupName) {
		this.groupName = groupName;
	}

	public String getHeadlTitle() {
		return headlTitle;
	}

	public void setHeadlTitle(String headlTitle) {
		this.headlTitle = headlTitle;
	}

	public String getMemberSum() {
		return memberSum;
	}

	public void setMemberSum(String memberSum) {
		this.memberSum = memberSum;
	}

	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}


	public Long getTaskId() {
		return taskId;
	}

	public void setTaskId(Long taskId) {
		this.taskId = taskId;
	}

	public String getTaskCode() {
		return taskCode;
	}

	public void setTaskCode(String taskCode) {
		this.taskCode = taskCode;
	}

	public static long getSerialversionuid() {
		return serialVersionUID;
	}

	public List<SendTuWenMembersInfoVO> getSuccessMembers() {
		return successMembers;
	}

	public void setSuccessMembers(List<SendTuWenMembersInfoVO> successMembers) {
		this.successMembers = successMembers;
	}

	public List<SendTuWenMembersInfoVO> getFailMembers() {
		return failMembers;
	}

	public void setFailMembers(List<SendTuWenMembersInfoVO> failMembers) {
		this.failMembers = failMembers;
	}

	public Long getMktActivityId() {
		return mktActivityId;
	}

	public void setMktActivityId(Long mktActivityId) {
		this.mktActivityId = mktActivityId;
	}
}
